@@ -1,10 +1,10 @@
 import json
-
+import os
 from pathlib import Path
-from .my_version import __version__
 from typing import Optional
-from .versions import clean_version
 
+from .my_version import __version__
+from .versions import clean_version
 
 # # log = logging.getLogger(__name__)
 # # logging.basicConfig(level=logging.INFO)
@@ -70,7 +70,18 @@ def make_manifest(folder: Path, family: str, port: str, version: str, release: s
 
         # sort the list
         for file in sorted(files):
-            mod_manifest["modules"].append({"file": str(file.relative_to(folder).as_posix()), "module": file.stem})
+            # if file is in folder, then use relative path only
+            # use old style relative path determination to support # python 3.8
+            file = Path(os.path.relpath(file, start=folder))
+            # if file.is_relative_to(folder):
+            #     file = file.relative_to(folder)
+
+            mod_manifest["modules"].append(
+                {
+                    "file": file.as_posix(),
+                    "module": file.stem,
+                }
+            )
 
         # write the the module manifest
         with open(folder / "modules.json", "w") as outfile:
